estimateExhaustiveRunTime: Estimates the time taken by minimization steps when preparing...

View source: R/RcppExports.R

estimateExhaustiveRunTimeR Documentation

Estimates the time taken by minimization steps when preparing a diagram with the exhaustive method at a given depth

Description

Estimates the time taken by minimization steps when preparing a diagram with the exhaustive method at a given depth

Usage

estimateExhaustiveRunTime(desc, maxlevel = 0L, byCol = 0L)

Arguments

desc

Description of sets, either as a file path, a list of lists, text or a previously created nVenn object (see nVennDiagram()).

maxlevel

Depth of the exhaustive search. See the maxlevel parameter of nVennDiagram() for details.

byCol

If the input is a text, this parameter indicates whether each set is a column (1) or a row (2). Defaults to 0, which means that the package will try to guess which possibility makes more sense.

Value

float Estimated time for steps 3 and 4 in seconds. In case of error, the returned value is -1.

Examples

estimateExhaustiveRunTime(exampledf, 4)

nVennR2 documentation built on July 14, 2026, 1:09 a.m.