getVennSvg: Get the svg code of an nVenn diagram

View source: R/RcppExports.R

getVennSvgR Documentation

Get the svg code of an nVenn diagram

Description

Get the svg code of an nVenn diagram

Usage

getVennSvg(nVennObj)

Arguments

nVennObj

nVennR2 object generated with nVennDiagram().

Details

The code returned by the funciton can be saved to a file and then edited with vectorial image software. This can be done directly with nVennDiagram() or plotVenn() by using the outFile param.

Value

String with svg code.

Examples

myv <- nVennDiagram(list(Set1=c("a", "b", "c"), Set2=c("a", "c", "d")), verbose=FALSE)
getVennSvg(myv)

nVennR2 documentation built on July 14, 2026, 1:09 a.m.