listVennRegions: Lists the elements in every region of the diagram

View source: R/RcppExports.R

listVennRegionsR Documentation

Lists the elements in every region of the diagram

Description

Lists the elements in every region of the diagram

Usage

listVennRegions(nVennObj, showEmpty = FALSE)

Arguments

nVennObj

nVennR2 object generated with nVennDiagram().

showEmpty

If true, lists every region, even if empty. If false (default), only lists regions containing elements.

Value

List of non-empty regions with the elements contained

Examples

myv <- nVennDiagram(list(Set1=c("a", "b", "c"), Set2=c("a", "c", "d")), verbose=FALSE)
mylist <- listVennRegions(myv)
mylist

nVennR2 documentation built on July 14, 2026, 1:09 a.m.