nVennDiagram: Creates nVenn plot

View source: R/RcppExports.R

nVennDiagramR Documentation

Creates nVenn plot

Description

Creates nVenn plot

Usage

nVennDiagram(
  desc,
  plot = TRUE,
  outFile = "",
  systemShow = FALSE,
  verbose = TRUE,
  maxlevel = 0L,
  byCol = 0L
)

Arguments

desc

Description of sets, either as a file path, a list of lists, text or a previously created nVenn object (see Details).

plot

If true (default), the resulting diagram is plotted. If false, only the object is returned.

outFile

If it contains a valid file path and plot is also true, the svg code of the plot will be saved in that path.

systemShow

If true, and plot is true, the function will attempt to open the resulting svg figure in the default editor. Defaults to false.

verbose

If true, shows messages as the nVenn plot is created.

maxlevel

If higher than zero, the simulation uses an exhaustive algorithm for the minimization steps. The number will represent the depth of the search. With a dept of one, every exchange of two regions will be explored. With a depth of two, every exchange of four regions will be explored. The computing resources necessary for this exploration increase extremely fast with the depth, so users are advised to use estimateExhaustiveRunTime() to determine whether it is feasible to use this procedure. The process will be unresponsive during the simulation and no messages will be shown, regardless of verbose.

byCol

If the input is a text, this parameter indicates whether each set is a column (1) or a row (2). Defaults to 0, which means that the package will try to guess which possibility makes more sense.

Details

A list of lists contains inner lists with a name, which will be the corresponding set name. A dataframe can be used in the same way.

The input can also be a text containing a table, possibly with missing values. If a text is provided, the package will try to guess if each set is encoded in columns or rows (use byCol to force) and which character separates fields (usually tab, space or comma). If the text describes a valid text file path, the contents of the file will be used.

Value

nVenn object. As a side effect, shows the nVenn plot. In case of error, returns null object.

Examples

myv <- nVennDiagram(list(Set1=c("a", "b", "c"), Set2=c("a", "c", "d")), verbose=FALSE)

nVennR2 documentation built on July 14, 2026, 1:09 a.m.