nVennR2-package: nVennR2: An Interface to 'nVenn2'

nVennR2-packageR Documentation

nVennR2: An Interface to 'nVenn2'

Description

Creates quasi-proportional Venn diagrams with an arbitrary number of sets. It is related to the old 'nVennR' package, but the algorithm and use have been reworked.

Author(s)

Maintainer: Victor Quesada quesadavictor@uniovi.es [copyright holder]

Authors:

See Also

Useful links:


nVennR2 documentation built on July 14, 2026, 1:09 a.m.