plotVenn: Plot nVenn diagram

View source: R/nVenn2.R

plotVennR Documentation

Plot nVenn diagram

Description

The nVenn diagram is generated in the plot window by default. If this is not possible, parameters outFile and systemShow may be used to export the SVG figure.

Usage

plotVenn(nVennObj, outFile = "", systemShow = FALSE)

Arguments

nVennObj

nVenn object.

outFile

Path to export the SVG figure. If empty, the figure is not exported.

systemShow

If true, and the system has a default SVG-editing program, opens the figure in the default editor.

Value

Nothing. If nVennObj is correct and the system supports it, the diagram is plotted in the plot window.

Examples

myv <- nVennDiagram(list(Set1=c("a", "b", "c"), Set2=c("a", "c", "d")), verbose=FALSE)
plotVenn(myv) 


nVennR2 documentation built on July 14, 2026, 1:09 a.m.