readVennSVG: Creates nVenn plot

View source: R/RcppExports.R

readVennSVGR Documentation

Creates nVenn plot

Description

Creates nVenn plot

Usage

readVennSVG(svgFile, plot = TRUE, outFile = "", systemShow = FALSE)

Arguments

svgFile

File name of an SVG or HTML file created by nVenn.

plot

If true (default), the resulting diagram is plotted. If false, only the object is returned.

outFile

If it contains a valid file path and plot is also true, the svg code of the plot will be saved in that path.

systemShow

If true, and plot is true, the function will attempt to open the resulting svg figure in the default editor. Defaults to false.

Details

In principle, this function should work with any SVG or HTML file created by nVenn, with either nVennR2, a web interface or nVennPy.

Value

nVenn object.

Examples

if (file.exists('example.svg')){
  readVennSVG('example.svg')
}

nVennR2 documentation built on July 14, 2026, 1:09 a.m.