setVennColor: Change a set color

View source: R/nVenn2.R

setVennColorR Documentation

Change a set color

Description

Change a set color

Usage

setVennColor(nVennObj, setName, color, plot = TRUE)

Arguments

nVennObj

nVenn object created with nVennDiagram().

setName

Name of the set.

color

New color. It is important to notice that this parameter must be a valid color in SVG format. The value is not checked, and therefore an incorrect value may break the plot in plotVenn() or lead to unexpected results.

plot

If true (default), plots the diagram after setting the color.

Value

nVenn object with the change in color for the set.

Examples

myv <- nVennDiagram(list(Set1=c("a", "b", "c"), Set2=c("a", "c", "d")), verbose=FALSE)
myv <- setVennColor(myv, "Set2", "black")
myv <- setVennColor(myv, "Set1", "#ffff00")

nVennR2 documentation built on July 14, 2026, 1:09 a.m.