setVennSkin: Set nVenn diagram appearance

View source: R/nVenn2.R

setVennSkinR Documentation

Set nVenn diagram appearance

Description

Set nVenn diagram appearance

Usage

setVennSkin(nVennObj, params, plot = TRUE)

Arguments

nVennObj

nVenn object generated with nVennDiagram().

params

List of graphical options, as in setVennOpts(), plus two special parameters: palette to set a color palette as in setVennPalette() and colors to change set colors as in setVennColors().

plot

If true (default), plots the diagram after the operation.

Details

Running this function is equivalent to running setVennOpts() repeatedly. The advantage is that setVennSkin() can set multiple parameters at the same time. The same params list can be used on multiple nVenn objects as a theme.

The only valid parameters for params are those in setVennOpts(), palette and colors.

Value

nVenn object with skin applied

Examples

theme <- list(opacity=0.2, lineWidth=2, fontSize=14, showRegions=FALSE,
              palette=2, colors=c("black"))
myv <- nVennDiagram(exampledf)
myv <- setVennSkin(myv, theme)

nVennR2 documentation built on July 14, 2026, 1:09 a.m.