| estimateExhaustiveRunTime | R Documentation |
Estimates the time taken by minimization steps when preparing a diagram with the exhaustive method at a given depth
estimateExhaustiveRunTime(desc, maxlevel = 0L, byCol = 0L)
desc |
Description of sets, either as a file path, a list of lists, text or a
previously created nVenn object (see |
maxlevel |
Depth of the exhaustive search. See the |
byCol |
If the input is a text, this parameter indicates whether each set is a column (1) or a row (2). Defaults to 0, which means that the package will try to guess which possibility makes more sense. |
float Estimated time for steps 3 and 4 in seconds. In case of error, the returned value is -1.
estimateExhaustiveRunTime(exampledf, 4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.