| getVennRegion | R Documentation |
Gets a list of the elements in a region of the diagram
getVennRegion(nVennObj, n)
nVennObj |
nVennR2 object generated with |
n |
Region, either as an integer or as a vector of set names. See Details |
An integer expresses a region by considering its binary representation in reverse. A 1 in a position means "belongs to" and a 0 or empty position means "does not belong to". Thus, the binary representation of 19 (10011), read from right to left, means "region that belongs to sets 1, 2 and 5 and does not belong to any other set".
A vector of set names expresses a region by giving the sets the region belongs to. It is understood that the region does not belong to any other set.
List of set names.
myv <- nVennDiagram(list(Set1=c("a", "b", "c"), Set2=c("a", "c", "d")), verbose=FALSE)
#Both commands are equivalent:
getVennRegion(myv, 3)
getVennRegion(myv, c("Set1", "Set2"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.