| nVennR2-package | R Documentation |
Creates quasi-proportional Venn diagrams with an arbitrary number of sets. It is related to the old 'nVennR' package, but the algorithm and use have been reworked.
Maintainer: Victor Quesada quesadavictor@uniovi.es [copyright holder]
Authors:
Victor Quesada quesadavictor@uniovi.es [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.