| plotVenn | R Documentation |
The nVenn diagram is generated in the plot window by default. If this is not possible, parameters outFile and systemShow may be used to export the SVG figure.
plotVenn(nVennObj, outFile = "", systemShow = FALSE)
nVennObj |
nVenn object. |
outFile |
Path to export the SVG figure. If empty, the figure is not exported. |
systemShow |
If true, and the system has a default SVG-editing program, opens the figure in the default editor. |
Nothing. If nVennObj is correct and the system supports it, the
diagram is plotted in the plot window.
myv <- nVennDiagram(list(Set1=c("a", "b", "c"), Set2=c("a", "c", "d")), verbose=FALSE)
plotVenn(myv)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.