| readVennSVG | R Documentation |
Creates nVenn plot
readVennSVG(svgFile, plot = TRUE, outFile = "", systemShow = FALSE)
svgFile |
File name of an SVG or HTML file created by nVenn. |
plot |
If true (default), the resulting diagram is plotted. If false, only the object is returned. |
outFile |
If it contains a valid file path and |
systemShow |
If true, and |
In principle, this function should work with any SVG or HTML file created by nVenn, with either nVennR2, a web interface or nVennPy.
nVenn object.
if (file.exists('example.svg')){
readVennSVG('example.svg')
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.