| setVennColor | R Documentation |
Change a set color
setVennColor(nVennObj, setName, color, plot = TRUE)
nVennObj |
nVenn object created with |
setName |
Name of the set. |
color |
New color. It is important to notice that this parameter must be
a valid color in SVG format. The value is not checked, and therefore an
incorrect value may break the plot in |
plot |
If true (default), plots the diagram after setting the color. |
nVenn object with the change in color for the set.
myv <- nVennDiagram(list(Set1=c("a", "b", "c"), Set2=c("a", "c", "d")), verbose=FALSE)
myv <- setVennColor(myv, "Set2", "black")
myv <- setVennColor(myv, "Set1", "#ffff00")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.