| setVennSkin | R Documentation |
Set nVenn diagram appearance
setVennSkin(nVennObj, params, plot = TRUE)
nVennObj |
nVenn object generated with |
params |
List of graphical options, as in |
plot |
If true (default), plots the diagram after the operation. |
Running this function is equivalent to running setVennOpts() repeatedly.
The advantage is that setVennSkin() can set multiple parameters at the
same time. The same params list can be used on multiple nVenn objects
as a theme.
The only valid parameters for params are those in setVennOpts(),
palette and colors.
nVenn object with skin applied
theme <- list(opacity=0.2, lineWidth=2, fontSize=14, showRegions=FALSE,
palette=2, colors=c("black"))
myv <- nVennDiagram(exampledf)
myv <- setVennSkin(myv, theme)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.